#ifndef __CMDREPLYINFO_H__
#define __CMDREPLYINFO_H__

#include "CmdReply.h"

namespace Aspera {

namespace Command {

    class Buffer;

    /*! \brief
    *  Class to hold the remote server information
    */
    class CmdReplyInfo : public CmdReply
    {

    private:
        const static char InfoPlatform  = 0x01;
        const static char InfoVersion   = 0x02;
        const static char InfoLang      = 0x03;
        const static char InfoTerritory = 0x04;
        const static char InfoCodeset   = 0x05;
        const static char InfoLCCtype   = 0x06;
        const static char InfoLCNumeric = 0x07;
        const static char InfoLCTime    = 0x08;
        const static char InfoLCAll     = 0x09;
        const static char InfoDev       = 0x0A;

    private:
        char *platform ;
        char *version  ;
        char *lang     ;
        char *territory;
        char *codeset  ;
        char *LCCtype  ;
        char *LCNumeric;
        char *LCTime   ;
        char *LCAll    ;
        char **driveList;
        int driveCount;

    public:
        CmdReplyInfo(CommandClientImpl *cc);
        ~CmdReplyInfo();
        int processMsgBuffer(Buffer *rawBuffer);
        void printReply();
        /*! \brief
        *  Returns the Platform of the remote server
        */
        char* getPlatform();
        /*! \brief
        *  Returns the FASP Version of the remote server
        */
        char* getVersion();
        /*! \brief
        *  Returns the language of the remote server
        */
        char* getLang();
        /*! \brief
        *  Returns the territory set on the remote server
        */
        char* getTerritory();
        /*! \brief
        *  Returns the codeset being used by the remote server
        */
        char* getCodeSet();
        //getDriveList
    };
}
}
#endif
